TRAVA_VAULT_ETH = {
    "name": "Trava Vault",
    "rewardToken": "0x186d0ba3dfc3386c464eecd96a61fbb1e2da00bf",
    "reservesList": {
        "0xbf576c63c30e1ebb637138ee1c67a570ff70223d": {
            "vaultName": "rtrava",
            "tokenIn": "0x044ede67afdb0f56d7451bb3aaccaeab3f772fad",
            "metadata": {
                "vaultType": "base",
                "token": "0x044ede67afdb0f56d7451bb3aaccaeab3f772fad"
            }
        },
        "0x84d92a3d61ec158dcf878ff24ebdcf6b2b5ec1fa": {
            "vaultName": "trava",
            "tokenIn": "0x186d0ba3dfc3386c464eecd96a61fbb1e2da00bf",
            "metadata": {
                "vaultType": "base",
                "token": "0x186d0ba3dfc3386c464eecd96a61fbb1e2da00bf"
            }
        }
    }
}
